local game = {}
local gameBoard = require("../game_board")
local tetromino = require("tetromino")

function game:load()
    local width = love.graphics.getWidth()
    local height = love.graphics.getHeight()
    gameBoard:load(width, height)

    love.math.setRandomSeed(os.time())
    local r = love.math.random(1, 7)

    ActivePiece = tetromino:new(r, math.floor(gameBoard.width / 2))
end

function game:draw()
    gameBoard:draw()

    if ActivePiece and not ActivePiece.isLocked then
        ActivePiece:draw(gameBoard)
    end
end

function game:update(dt, state)
    -- Tetromino:update returns true if piece locked
    local hasControl = true
    if ActivePiece:update(dt, gameBoard, state) then
        hasControl = false
        gameBoard:clearRows()

        gameBoard:print()
        print("Gameboard W: " .. gameBoard.width .. ", H: " .. gameBoard.height)
        print("\n")

        local r = love.math.random(1, 7)
        ActivePiece = tetromino:new(r, math.floor(gameBoard.width / 2))
        hasControl = true
    end

    if hasControl then
        if love.keyboard.isDown("a") then
            ActivePiece:move(dt, -1, gameBoard)
        elseif love.keyboard.isDown("d") then
            ActivePiece:move(dt, 1, gameBoard)
        elseif love.keyboard.isDown("s") then
            ActivePiece:increaseDropSpeed()
        end
    end
end

function game:keyreleased(key)
    if key == "s" then
        ActivePiece:resetDropSpeed()
    end
end

function game:keypressed(key)
    if key == "i" then
        ActivePiece:rotateClockwise(gameBoard)
    end

    if key == "u" then
        ActivePiece:rotateCounterClockwise(gameBoard)
    end

    if key == "r" then
        game:load()
    end
end

return game
